#
# spec file for package python-trove-classifiers
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-trove-classifiers%{?psuffix}
Version:        2025.3.19.19
Release:        1.1
Summary:        Canonical source for classifiers on PyPI
License:        Apache-2.0
URL:            https://github.com/pypa/trove-classifiers
Source:         https://files.pythonhosted.org/packages/source/t/trove-classifiers/trove_classifiers-%{version}.tar.gz
BuildRequires:  %{python_module calver}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module pytest}
%endif
BuildArch:      noarch
%python_subpackages

%description
Classifiers categorize projects per PEP 301. Use this package to validate classifiers in packages for PyPI upload or download.

%prep
%setup -q -n trove_classifiers-%{version}

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/trove_classifiers
%{python_sitelib}/trove_classifiers-%{version}.dist-info
%endif

%changelog
* Sun Mar 30 2025 Dirk Müller <dmueller@suse.com>
- update to 2025.3.19.19:
  * fixup Django classifiers
* Tue Feb 25 2025 Dirk Müller <dmueller@suse.com>
- update to 2025.2.18.16:
  * add Plone 6.2 classifier
* Mon Feb 10 2025 Dirk Müller <dmueller@suse.com>
- update to 2025.1.15.22:
  * Add CUDA 12.6 classifier
  * Remove unused licenses
  * Add upcoming django version
  * Add term for quantum computing
  * Add Django trove classifiers for 5 and upcoming 5.2 release
* Tue Nov 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2024.10.21.16:
  * Chore: update calver to include hour (#191)
  * Add Django trove classifiers for 5 and upcoming 5.2 release. (#193)
  * Chore: update github actions (#192)
  * Update CMU to include SPDX in parentheses (#190)
  * Add classifier for MIT-CMU licence (#189)
  * Add Odoo 18 trove classifier (#187)
  * Add CUDA 12.3-12.5 classifiers (#182)
  * Add Blue Oak Model License (#181)
  * Add Trove classifier for Django 5.1 (#179)
  * Add Trove classifier for Python 3.14 (#178)
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.4.10:
  * added more trove classifiers
* Sat Apr  6 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.3.25:
  * added more trove classifiers
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.3.3:
  * added more trove classifiers
* Sun Jan 21 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1.8:
  * added more CAN classifiers
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.11.13:
  * Update release.yml
  * Added PySimpleGUI versions 4 and 5 as a Framework
  * Add Odoo 17 trove classifier
* Mon Oct 30 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 2023.10.18:
  * Add Framework :: Mkdocs classifier (#154)
- update to 2023.10.17:
  * Add the `NVIDIA CUDA :: 12 :: 12.2` classifier. (#155)
  * Remove the accidental dangling whitespace from CUDA 12.
- update to 2023.9.19:
  * Add Trove classifier for Django 5.0 (#153)
- update to 2023.8.7:
  * Add Trove classifier for Python 3.13 (#150)
- update to 2023.7.6:
  * add Oceanography to Scientific/Engineering (#149)
    This seemed to be the place to add a new one -- please let me
    know if there's another way to propose a new classifier.
  - Note: we could do something like:
    Met/Ocean Science, but there is already Atmospheric
    Science, I figured Oceanography made sense.
- update to 2023.5.24:
  * Add identifier "Programming Language :: Lua" (#145)
- update to 2023.5.22:
  * Add Plone 6.1 classifier (#147)
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.5.2:
  * fix: incorrect specification of mypy section in pyproject.toml
  * Add Pydantic :: 2 classifier.
  * Add JSON and JSON Schema classifiers
  * Add classifier for Wagtail 5
  * Add `Environment :: WebAssembly` classifiers (#129)
  * Add Django :: 4.2 classifier.
  * Add Pycsou Framework trove-classifier
* Mon May  1 2023 Ben Greiner <code@bnavigator.de>
- Test in multibuild: pytest requires python-iniconfig which
  cycles back as build requirement in any build involving hatchling
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Tue Apr 18 2023 Matej Cepl <mcepl@suse.com>
- Switch to single spec version build for PSP
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v2022.12.1
  * Add django CMS 4.1 (#122)
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v2022.10.19
  * add cuda 11.8
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2022.9.26
  * Add "Framework :: Odoo :: 16.0" classifier (#117)
  * The Odoo 16.0 branch has been created and it will be released in October.
* Wed Jul 13 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for v2022.6.26
